@@ -3,12 +3,8 @@ from __future__ import print_function, unicode_literals
 
 import os
 import sys
-import logging
 import click
 
-# add mldock package to path
-sys.path.insert(1, ".")
-
 from mldock.__version__ import __version__
 from mldock.__init__ import MLDOCK_LOGO
 # from mldock.command.initialize import init
@@ -27,7 +23,7 @@ CLI_VERSION = 'Version: cli {}'.format(__version__)
 @click.pass_context
 def cli(ctx, verbose):
     """
-    CLI tool built to add simple functionality to sagify development.
+    A CLI that helps put machine learning in places that empower data scientists.
     """
     _FILE_DIR_PATH = os.path.dirname(os.path.realpath(__file__))
     logger=configure_logger('mldock', verbose=verbose)
