@@ -17,7 +17,7 @@ logger=logging.getLogger('mldock')
 @click.group()
 def cloud():
     """
-    Commands for local operations: train and deploy
+    Commands for cloud operations
     """
     pass
 
@@ -54,9 +54,7 @@ def cloud():
 @click.pass_obj
 def push(obj, dir, build, provider, no_cache):
     """
-    Command to push docker container image to ECR using your default AWS sdk credentials.
-
-    note: Override default AWS credentials by providing AWS_DEFAULT_PROFILE environment variable.
+    Command to push docker container image to Cloud Container Registry
     """
     helper_library_path = obj['helper_library_path']
     try:
