@@ -26,7 +26,7 @@ def reset_terminal():
 @click.group()
 def container():
     """
-    Manage and create new container projects. Create new templates from mldock container projects.
+    Commands to create, update and manage container projects and templates.
     """
     pass
 
@@ -37,9 +37,7 @@ def container():
 @click.pass_obj
 def create_template(obj, name, dir, out):
     """
-    Creates an MLDock ready container template
-
-    remote => (giturl) => https://github.com/sdushantha/gitdir/blob/master/gitdir/gitdir.py
+    Command to create a mldock enabled container template
     """
     helper_library_path=obj['helper_library_path']
 
@@ -68,7 +66,7 @@ def create_template(obj, name, dir, out):
 @click.pass_obj
 def init(obj, dir, testing_framework, service, no_prompt, container_only, template):
     """
-    Command to initialize container configs required by sagemaker-training.
+    Command to initialize mldock enabled container
     """
     reset_terminal()
     helper_library_path=obj['helper_library_path']
@@ -158,7 +156,10 @@ def init(obj, dir, testing_framework, service, no_prompt, container_only, templa
                 template_dir=template
             )
         elif platform == "sagemakerv2":
-            # pass down any information like hyperparameters, etc
+            # get list of dataset names
+            mldock_data = mldock_config.get("data", None)
+            input_config_config = _extract_data_channels_from_mldock(mldock_data)
+            _write_json(input_config_config, Path(dir,'config/inputdataconfig.json'))
             sagemaker_init(
                 dir=working_directory_manager.get_working_dir(),
                 helper_library_path=helper_library_path,
@@ -209,7 +210,7 @@ def update(obj, dir):
     reset_terminal()
     helper_library_path=obj['helper_library_path']
     try:
-        logger.info("Initializing MLDock config")
+        logger.info("Loading MLDock config")
         mldock_manager = MLDockConfigManager(
             filepath=os.path.join(dir, ".mldock.json")
         )
@@ -289,11 +290,35 @@ def update(obj, dir):
         logger.error("{}".format(e))
         sys.exit(-1)
 
+@click.command()
+@click.option('--dir', help='Set the working directory for your sagify container.', required=True)
+@click.pass_obj
+def summary(obj, dir):
+    """
+    Command to initialize container configs required by sagemaker-training.
+    """
+    try:
+        logger.info("Loading MLDock config")
+        mldock_manager = MLDockConfigManager(
+            filepath=os.path.join(dir, ".mldock.json")
+        )
+
+        states = mldock_manager.get_state()
+
+        for state in states:
+            click.echo(click.style(state["name"], bg='blue'), nl=True)
+            click.echo(click.style(state["message"], fg='white'), nl=True)
+
+        logger.info("\nlocal container was updated! ヽ(´▽`)/")
+    except Exception as e:
+        logger.error("{}".format(e))
+        sys.exit(-1)
 
 def add_commands(cli):
 
     cli.add_command(init)
     cli.add_command(update)
     cli.add_command(create_template)
+    cli.add_command(summary)
 
 add_commands(container)
