@@ -52,10 +52,7 @@ def pretty_build_logs(line: dict):
 @click.option('--stage', help='environment to stage.')
 @click.pass_obj
 def build(obj, dir, no_cache, tag, stage):
-    """build image using docker
-
-    Args:
-        dir (str): directory containing model assets
+    """Command to build container locally
     """
     helper_library_path = obj['helper_library_path']
     mldock_manager = MLDockConfigManager(
@@ -119,7 +116,7 @@ def build(obj, dir, no_cache, tag, stage):
 @click.option('--host', help='host url at which model is served', type=str, default='http://127.0.0.1:8080/invocations')
 def predict(payload, content_type, host):
     """
-    Command to run curl predict against an host served on localhost:8080
+    Command to execute prediction request against ml endpoint
     """
     try:
         if payload is None:
@@ -139,12 +136,28 @@ def predict(payload, content_type, host):
 
 @click.command()
 @click.option('--dir', help='Set the working directory for your mldock container.', required=True)
+@click.option(
+    '--params',
+    '-p',
+    help='(Optional) Hyperparameter override used in experiment.',
+    nargs=2,
+    type=click.Tuple([str, str]),
+    multiple=True
+)
+@click.option(
+    '--env_vars',
+    '-e',
+    help='(Optional) Hyperparameter override used in experiment.',
+    nargs=2,
+    type=click.Tuple([str, str]),
+    multiple=True
+)
 @click.option('--tag', help='docker tag', type=str, default='latest')
 @click.option('--stage', help='environment to stage.')
 @click.pass_obj
-def train(obj, dir, tag, stage):
+def train(obj, dir, params, env_vars, tag, stage):
     """
-    Command to train ML model(s) locally
+    Command to run training locally on localhost
     """
     mldock_manager = MLDockConfigManager(
         filepath=os.path.join(dir, ".mldock.json")
@@ -176,9 +189,27 @@ def train(obj, dir, tag, stage):
         sys.exit(-1)
 
     project_env_vars = mldock_config.get('environment', {})
+
+    for env_var in env_vars:
+        key_, value_ = env_var
+        print(key_, value_)
+        project_env_vars.update(
+            {key_: value_}
+        )
+
+    hyperparameters = mldock_config.get('hyperparameters', {})
+
+    # override hyperparameters
+    for param in params:
+        key_, value_ = param
+        print(key_, value_)
+        hyperparameters.update(
+            {key_: value_}
+        )
+
     env_vars = collect_mldock_environment_variables(
         stage=stage,
-        hyperparameters=mldock_config.get('hyperparameters', {}),
+        hyperparameters=hyperparameters,
         **project_env_vars
     )
     try:
@@ -223,13 +254,29 @@ def train(obj, dir, tag, stage):
 
 @click.command()
 @click.option('--dir', help='Set the working directory for your mldock container.', required=True)
+@click.option(
+    '--params',
+    '-p',
+    help='(Optional) Hyperparameter override used in experiment.',
+    nargs=2,
+    type=click.Tuple([str, str]),
+    multiple=True
+)
+@click.option(
+    '--env_vars',
+    '-e',
+    help='(Optional) Hyperparameter override used in experiment.',
+    nargs=2,
+    type=click.Tuple([str, str]),
+    multiple=True
+)
 @click.option('--tag', help='docker tag', type=str, default='latest')
 @click.option('--port', help='host url at which model is served', type=str, default='8080')
 @click.option('--stage', help='environment to stage.')
 @click.pass_obj
-def deploy(obj, dir, tag, port, stage):
+def deploy(obj, dir, params, env_vars, tag, port, stage):
     """
-    Command to deploy ML model(s) locally
+    Command to deploy ml container on localhost
     """
     helper_library_path=obj['helper_library_path']
     mldock_manager = MLDockConfigManager(
@@ -262,6 +309,23 @@ def deploy(obj, dir, tag, port, stage):
         sys.exit(-1)
 
     project_env_vars = mldock_config.get('environment', {})
+
+    for env_var in env_vars:
+        key_, value_ = env_var
+        print(key_, value_)
+        project_env_vars.update(
+            {key_: value_}
+        )  
+    hyperparameters = mldock_config.get('hyperparameters', {})
+
+    # override hyperparameters
+    for param in params:
+        key_, value_ = param
+        print(key_, value_)
+        hyperparameters.update(
+            {key_: value_}
+        )
+
     env_vars = collect_mldock_environment_variables(
         stage=stage,
         hyperparameters=mldock_config.get('hyperparameters', {}),
