@@ -199,7 +199,7 @@ class MLDockConfigManager(BaseConfigManager):
     config = {}
 
     def setup_config(self):
-
+        click.secho("Base Setup", bg='blue')
         self.ask_for_image_name()
         self.ask_for_platform_name()
         self.ask_for_mldock_module_dir()
@@ -210,7 +210,7 @@ class MLDockConfigManager(BaseConfigManager):
         """prompt user for image name
         """
         image_name = click.prompt(
-            text="Set your image name: ",
+            text=click.style("Set your image name: ", fg='bright_blue'),
             default=self.config.get('image_name', 'my_ml_container')
         )
 
@@ -222,7 +222,7 @@ class MLDockConfigManager(BaseConfigManager):
         """prompt user for platform name
         """
         platform_name = click.prompt(
-            text="Set your platform name:",
+            text=click.style("Set your platform name: ", fg='bright_blue'),
             default=self.config.get('platform', 'generic')
         )
 
@@ -234,7 +234,7 @@ class MLDockConfigManager(BaseConfigManager):
         """prompt user for container dir name
         """
         container_dir_name = click.prompt(
-            text="Set your container dir name:",
+            text=click.style("Set your container dir name: ", fg='bright_blue'),
             default=self.config.get('container_dir', 'container')
         )
 
@@ -247,19 +247,77 @@ class MLDockConfigManager(BaseConfigManager):
         """
         
         mldock_module_dir = click.prompt(
-            text="Set mldock module dir: ",
+            text=click.style("Set mldock module dir: ", fg='bright_blue'),
             default=self.config.get('mldock_module_dir', 'src')
         )
 
         self.config.update({
             'mldock_module_dir': mldock_module_dir
         })
+    
+    @staticmethod
+    def _format_data_node_item(item, base_path='data'):
+
+        new_key = item["channel"]
+        new_value = os.path.join(base_path, item["channel"], item["filename"])
+        return "\t{KEY} : {VALUE}".format(KEY=new_key, VALUE=new_value)
+
+    def _format_data_node(self):
+
+        output = []
+        
+        for item in self.config['data']:
+            output.append(self._format_data_node_item(item, base_path='data'))
+
+        return "\n".join(output)
+
+    def _format_stage_node(self):
+
+        output = []
+        
+        for key_, value_ in self.config['stages'].items():
+            image_and_tag = "{}:{}".format(self.config['image_name'], value_["tag"])
+            output.append("\t{} : {}".format(key_, image_and_tag))
+
+        return "\n".join(output)
+
+    @staticmethod
+    def _format_nodes(config):
+
+        output = []
+        
+        for key_, value_ in config.items():
+            output.append("\t{} : {}".format(key_, value_))
+
+        return "\n".join(output)
+
+    def get_state(self):
+        """pretty prints a json config to terminal
+        """
+        config = self.config.copy()
+
+        config.pop("stages")
+        formatted_stages = self._format_stage_node()
+        hyperparameters = config.pop("hyperparameters")
+        config.pop("data")
+        formatted_data_node = self._format_data_node()
+        environment = config.pop("environment")
+
+        states = []
+
+        states.append({"name": "Base Setup", "message": self._format_nodes(config)})
+        states.append({"name": "Data Channels", "message": formatted_data_node})
+        states.append({"name": "Stages", "message": formatted_stages})
+        states.append({"name": "Hyperparameters", "message": self._format_nodes(hyperparameters)})
+        states.append({"name": "Environment Variables", "message": self._format_nodes(environment)})
+
+        return states
 
     def ask_for_requirements_file_name(self):
         """prompt user for image name
         """
         requirements_file_name = click.prompt(
-            text="Set full path to requirements: ",
+            text=click.style("Set full path to requirements: ", fg='bright_blue'),
             default=self.config.get('requirements_dir', 'requirements.txt')
         )
 
@@ -380,9 +438,9 @@ class StageConfigManager(BaseConfigManager):
     def ask_for_stages(self):
         """prompt user for stages
         """
+        click.secho("Stages", bg='blue', nl=True)
         while True:
-            click.secho("Stages", bg='green', nl=True)
-            click.secho("Add a stage by following the prompts", fg='green', nl=True)
+            click.echo(click.style("Add a development stage. ", fg='bright_blue')+"(Follow the prompts)", nl=True)
             stage_name = click.prompt(
                 text="Stage name: ",
                 default="end",
@@ -422,25 +480,26 @@ class HyperparameterConfigManager(BaseConfigManager):
     def ask_for_hyperparameters(self):
         """prompt user for hyperparameters
         """
+        click.secho("Hyperparameters", bg='blue', nl=True)
         while True:
-            name_value_pair = click.prompt(
-                text="Add a hyperparameter. (Expects name:value). Hit enter to continue.",
+            click.echo(click.style("Add a hyperparameter. ", fg='bright_blue')+"(Follow prompts)", nl=True)
+            hparam_name = click.prompt(
+                text="Hyperparameter (name): ",
                 default="end",
                 show_default=False,
                 type=str
             )
-            if name_value_pair == "end":
+            if hparam_name == "end":
                 break
-            elif "=" in name_value_pair and not name_value_pair == "name=value":
-                name, value = name_value_pair.split("=",1)
-                if value.isdigit():
-                    value = int(value)
-                elif self.is_float(value):
-                    value = float(value)
-                logger.debug("Adding {}={}".format(name, value))
-                self.config.update({name: value})
             else:
-                logger.warning("Expected format as name=value. Skipping")
+                hparam_value = click.prompt(
+                    text="Set value: ",
+                    default=self.config.get(hparam_name, None)
+                )
+
+                self.config.update(
+                    {hparam_name: hparam_value}
+                )
 
 class EnvironmentConfigManager(BaseConfigManager):
     """Environment Config Manager for mldock
@@ -468,43 +527,43 @@ class EnvironmentConfigManager(BaseConfigManager):
             return s
 
     def ask_for_env_vars(self):
-        """prompt user for hyperparameters
+        """prompt user for environment variables
         """
+        click.secho("Environment Variables", bg='blue', nl=True)
         while True:
-            name_value_pair = click.prompt(
-                text="Add a environment variable. (Expects name:value). Hit enter to continue.",
+            click.echo(click.style("Add a environment variable. ", fg='bright_blue')+"(Follow prompts)", nl=True)
+            env_var_name = click.prompt(
+                text="Environment Variable (name): ",
                 default="end",
                 show_default=False,
                 type=str
             )
-            if name_value_pair == "end":
+            if env_var_name == "end":
                 break
-            elif "=" in name_value_pair and not name_value_pair == "name=value":
-                name, value = name_value_pair.split("=",1)
-                value = self.parse_bool(value)
-                if isinstance(value, bool):
-                    pass
-                elif value.isdigit():
-                    value = int(value)
-                elif self.is_float(value):
-                    value = float(value)
-                logger.debug("Adding {}={}".format(name, value))
-                self.config.update({name: value})
             else:
-                logger.warning("Expected format as name=value. Skipping")
+                env_var_value = click.prompt(
+                    text="Set value: ",
+                    default=self.config.get(env_var_name, None)
+                )
+
+                self.config.update(
+                    {env_var_name: env_var_value}
+                )
 
 class InputDataConfigManager(BaseConfigManager):
     """InputData Config Manager for mldock
     """
-    def __init__(self, config: dict):
+    def __init__(self, config: dict, base_path: str = 'data'):
         self.config = config
+        self.base_path = base_path
 
     def ask_for_input_data_channels(self):
         """prompt user for hyperparameters
         """
+        click.secho("Input Data Channels", bg='blue', nl=True)
         while True:
             channel_filename_pair = click.prompt(
-                text="Add a data channel. (Expects channel/filename). Hit enter to continue.",
+                text=click.style("Add a data channel. ", fg='bright_blue')+"(Expects channel/filename). Hit enter to continue.",
                 default="end",
                 show_default=False,
                 type=str
